Notebook Client
===============

The ``bookstore.client.nb_client`` module
-----------------------------------------

.. module:: bookstore.client.nb_client

``NotebookClient``
~~~~~~~~~~~~~~~~~~

.. autoclass:: NotebookClient
   :members:

``NotebookClientCollection``
~~~~~~~~~~~~~~~~~~~~~~~~~~~~

.. autoclass:: NotebookClientCollection
   :members:

``CurrentNotebookClient``
~~~~~~~~~~~~~~~~~~~~~~~~~

.. autoclass:: CurrentNotebookClient
   :members:


``LiveNotebookRecord``
~~~~~~~~~~~~~~~~~~~~~~

.. autoclass:: LiveNotebookRecord
   :members:

``KernelInfo``
~~~~~~~~~~~~~~

.. autoclass:: KernelInfo
   :members:

``NotebookSession``
~~~~~~~~~~~~~~~~~~~

.. autoclass:: NotebookSession
   :members:

Helper Function
~~~~~~~~~~~~~~~

.. autofunction:: extract_kernel_id